==> boru-dweb-0.0.5-9a3969.tar: src/Http/Response.php <==
<?php
namespace boru\dweb\Http;

class Response
{
    /** @var int */
    private $status;
    /** @var array */
    private $headers;
    /** @var string|callable */
    private $body;
    /** @var bool */
    private $isStream = false;

    /**
     * @param int $status
     * @param array $headers
     * @param string $body
     */
    public function __construct($status = 200, array $headers = array(), $body = '')
    {
        if(is_array($body)) {
            $body = json_encode($body, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
            $headers['Content-Type'] = 'application/json';
        }
        $this->status  = (int)$status;
        $this->headers = $headers;
        $this->body    = (string)$body;
        $this->isStream = false;
    }

    /**
     * Create a streaming response. Body producer should echo output.
     *
     * @param array $headers
     * @param callable $producer function(): void
     * @param int $status
     * @return Response
     */
    public static function stream(array $headers, $producer, $status = 200)
    {
        $r = new self($status, $headers, '');
        $r->body = $producer;
        $r->isStream = true;
        return $r;
    }

    /** @return int */
    public function status() { return $this->status; }

    /** @return array */
    public function headers() { return $this->headers; }

    public function header($name, $default = null)
    {
        return isset($this->headers[$name]) ? $this->headers[$name] : $default;
    }

    /**
     * @param string $name
     * @param string $value
     * @return Response
     */
    public function withHeader($name, $value)
    {
        $this->headers[$name] = $value;
        return $this;
    }

    /**
     * @param string $name
     * @param string $value
     * @return Response
     */
    public function setHeader($name, $value)
    {
        $this->headers[$name] = $value;
        return $this;
    }

    /** @return bool */
    public function isStream() { return $this->isStream; }

    /**
     * @return string|callable
     */
    public function body() { return $this->body; }
}

==> boru-dweb-1.0.4-7b4292.tar: src/Http/Response.php <==
<?php
namespace boru\dweb\Http;

class Response
{
    /** @var int */
    private $status;
    /** @var array */
    private $headers;
    /** @var string|callable */
    private $body;
    /** @var bool */
    private $isStream = false;

    /**
     * @param int $status
     * @param array $headers
     * @param string $body
     */
    public function __construct($status = 200, array $headers = array(), $body = '')
    {
        if(is_array($body)) {
            $body = json_encode($body, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE | JSON_PRETTY_PRINT);
            $headers['Content-Type'] = 'application/json';
        }
        $this->status  = (int)$status;
        $this->headers = $headers;
        $this->body    = (string)$body;
        $this->isStream = false;
    }

    /**
     * Create a streaming response. Body producer should echo output.
     *
     * @param array $headers
     * @param callable $producer function(): void
     * @param int $status
     * @return Response
     */
    public static function stream($producer, array $headers = array(), $status = 200)
    {
        $r = new self($status, $headers, '');
        $r->body = $producer;
        $r->isStream = true;
        return $r;
    }

    /** @return int */
    public function status() { return $this->status; }

    /** @return array */
    public function headers() { return $this->headers; }

    public function header($name, $default = null)
    {
        return isset($this->headers[$name]) ? $this->headers[$name] : $default;
    }

    /**
     * @param string $name
     * @param string $value
     * @return Response
     */
    public function withHeader($name, $value)
    {
        $this->headers[$name] = $value;
        return $this;
    }

    /**
     * @param string $name
     * @param string $value
     * @return Response
     */
    public function setHeader($name, $value)
    {
        $this->headers[$name] = $value;
        return $this;
    }

    /** @return bool */
    public function isStream() { return $this->isStream; }

    /**
     * @return string|callable
     */
    public function body() { return $this->body; }
}
